@@ -1,4 +1,5 @@
 import pymysql
+import pymssql
 from pymoran.strtool import StrClass
 
 
@@ -10,7 +11,7 @@ class MySQLClient:
         :return {bool} True/False
         '''
         # 打开数据库连接
-        self.db = pymysql.connect(
+        self.conn = pymysql.connect(
             host=dbdata['host'],
             user=dbdata['user'],
             password=dbdata['password'],
@@ -18,11 +19,11 @@ class MySQLClient:
             port=dbdata['port']
         )
         # 使用cursor()方法获取操作游标
-        self.cursor = self.db.cursor()
+        self.cursor = self.conn.cursor()
         self.strclass = StrClass()
 
     def close(self):
-        self.db.close()
+        self.conn.close()
 
     def creat_table(self, name: str, field: list, close: bool = True):
         '''
@@ -39,7 +40,7 @@ class MySQLClient:
             result = True
         except:
             # 如果发生错误则回滚
-            self.db.rollback()
+            self.conn.rollback()
             result = False
         if close:
             self.close()
@@ -70,11 +71,11 @@ class MySQLClient:
             # 执行sql语句
             self.cursor.execute(sql)
             # 提交到数据库执行
-            self.db.commit()
+            self.conn.commit()
             result = True
         except:
             # 如果发生错误则回滚
-            self.db.rollback()
+            self.conn.rollback()
             result = False
         if close:
             self.close()
@@ -96,21 +97,21 @@ class MySQLClient:
         result = False
         values = []
         for d in data:
-            val = '(%s)' % (','.join(str(v) for v in d))
+            val = '(%s)' % (','.join(str(v) if type(v)!= str else "'"+v+"'" for v in d))
             values.append(val)
         sql = 'INSERT INTO %s (%s) VALUES %s' % (table, ','.join(field),
                                                  ','.join(values))
         try:
             # 如果连接断开则重连
-            self.db.ping(reconnect=True)
+            self.conn.ping(reconnect=True)
             # 执行sql语句
             self.cursor.execute(sql)
             # 提交到数据库执行
-            self.db.commit()
+            self.conn.commit()
             result = True
         except:
             # 如果发生错误则回滚
-            self.db.rollback()
+            self.conn.rollback()
             result = False
         if close:
             self.close()
@@ -179,6 +180,7 @@ class MySQLClient:
             table,
             where_str
         )
+        results=(0,)
         try:
             # 执行SQL语句
             self.cursor.execute(sql)
@@ -219,11 +221,11 @@ class MySQLClient:
             # 执行SQL语句
             self.cursor.execute(sql)
             # 提交到数据库执行
-            self.db.commit()
+            self.conn.commit()
             result = True
         except:
             # 发生错误时回滚
-            self.db.rollback()
+            self.conn.rollback()
             result = False
         # 关闭数据库连接
         if close:
@@ -250,17 +252,58 @@ class MySQLClient:
             # 执行SQL语句
             self.cursor.execute(sql)
             # 提交到数据库执行
-            self.db.commit()
+            self.conn.commit()
             result = True
         except:
             # 发生错误时回滚
-            self.db.rollback()
+            self.conn.rollback()
             result = False
         # 关闭数据库连接
         if close:
             self.close()
         return result
 
+class MSSQLClient:
+    def __init__(self,dbdata:dict) -> None:
+        '''
+        初始化数据库连接
+        :param dbdata 连接配置，包含server，database
+        '''
+        self.conn=pymssql.connect(
+            server=dbdata['server'],
+            database=dbdata['database']
+        )
+        self.cursor=self.conn.cursor()
+
+    def close(self):
+        self.conn.close()
+
+    def find(self,close: bool = True):
+        data=[]
+        # 关闭数据库连接
+        if close:
+            self.close()
+        return data
+
+    def delete(self,sql,close:bool=True):
+        '''
+        删除数据，查询条件数据建议使用html_escape转码保证数据查询安全
+        :param table 表名
+        :param query 查询条件，默认为空
+        :param close 是否自动关闭数据库连接，默认True
+        :return {bool} True/False
+        '''
+
+    def updata(self,sql,close:bool=True):
+        # self.cursor.execute(sql)
+        # self.conn.commit()
+        # 关闭数据库连接
+        if close:
+            self.close()
+        return True
+
+    
+
 
 if __name__ == '__main__':
     pass
