@@ -45,7 +45,7 @@ class FileClass:
             if os.path.isdir(cpath):
                 # 如果路径为目录，则保存到目录列表
                 dirpath.append(cpath)
-            if os.path.isfile(path):
+            if os.path.isfile(cpath):
                 # 如果路径为文件，则删除文件
                 os.remove(cpath)
         # 循环删除剩下的空目录
